@@ -11,4 +11,10 @@ with_collate <- function(locale, code) {
   force(code)
 }
 
-sort_c <- function(x, ...) with_collate("C", sort(x, ...))
+sort_c <- function(x, ...) {
+  with_collate("C", sort(x, ...))
+}
+
+order_c <- function(x, ...) {
+  with_collate("C", order(x, ...))
+}
