@@ -17,8 +17,11 @@ print.rd <- function(x, ...) {
 }
 
 escape <- function(x) UseMethod("escape")
+#' @export
 escape.NULL <- function(x) NULL
+#' @export
 escape.rd <- function(x) x
+#' @export
 escape.character <- function(x) {
   # wrap_usage uses \u{A0}, the unicode non-breaking space, which
   # is not necessarily valid in windows locales. useBytes is a quick
@@ -68,48 +71,6 @@ get_tags <- function(rd, tag) {
   Filter(function(x) identical(attr(x, "Rd_tag"), tag), rd)
 }
 
-rd2text <- function(x) {
-  chr <- as_character_rd(structure(x, class = "Rd"), deparse = TRUE)
-  paste(chr, collapse = "")
-}
-
-tweak_links <- function(x, package) {
-  tag <- attr(x, "Rd_tag")
-
-  if (is.list(x)) {
-    if (!is.null(tag) && tag == "\\link") {
-      opt <- attr(x, "Rd_option")
-      if (is.null(opt)) {
-        if (has_topic(x[[1]], package)) {
-          attr(x, "Rd_option") <- structure(package, Rd_tag = "TEXT")
-        }
-      } else {
-        if (is.character(opt) && length(opt) == 1 && substr(opt, 1, 1) == "=") {
-          topic <- substr(opt, 2, nchar(opt))
-
-          if (has_topic(topic, package)) {
-            file <- find_topic_in_package(package, topic)
-            attr(x, "Rd_option") <- structure(paste0(package, ":", file), Rd_tag = "TEXT")
-          }
-        } else if (grepl(":", opt)) {
-          # need to fix the link to point to a file
-          target <- str_split_fixed(opt, ":", n = 2)
-          file <- try_find_topic_in_package(
-            target[1],
-            target[2],
-            where = " in inherited text"
-          )
-          attr(x, "Rd_option") <- structure(paste0(target[1], ":", file), Rd_tag = "TEXT")
-        }
-      }
-    } else if (length(x) > 0) {
-      x[] <- map(x, tweak_links, package = package)
-    }
-  }
-
-  x
-}
-
 # helpers -----------------------------------------------------------------
 
 parse_rd <- function(x) {
@@ -125,7 +86,7 @@ parse_rd <- function(x) {
 # Generated in .onLoad()
 as_character_rd <- NULL
 make_as_character_rd <- function() {
-  # "as.character.Rd" appears to be missing \href in TWOARGS
+  # "as.character.Rd" appears to a few commands in TWOARGS
   # this code hacks the body of the function to add it
   fn <- internal_f("tools", "as.character.Rd")
 
@@ -135,7 +96,7 @@ make_as_character_rd <- function() {
     return(fn)
   }
 
-  body[[idx]][[3]] <- call_modify(body[[idx]][[3]], "\\href")
+  body[[idx]][[3]] <- call_modify(body[[idx]][[3]], "\\href", "\\ifelse", "\\if")
   body(fn) <- body
   fn
 }
@@ -143,8 +104,9 @@ make_as_character_rd <- function() {
 has_topic <- function(topic, package) {
   tryCatch(
     {
-      out <- utils::help((topic), package = (package))
-      length(out) == 1
+      out <- exec("help", topic, package, .env = global_env())
+      inherits(out, "dev_topic") ||
+        (inherits(out, "help_files_with_topic") && length(out) == 1)
     },
     error = function(c) FALSE
   )
